@@ -32,6 +32,8 @@ pub mod create_group_options;
 pub use self::create_group_options::CreateGroupOptions;
 pub mod create_inbox_dto;
 pub use self::create_inbox_dto::CreateInboxDto;
+pub mod create_inbox_forwarder_options;
+pub use self::create_inbox_forwarder_options::CreateInboxForwarderOptions;
 pub mod create_inbox_ruleset_options;
 pub use self::create_inbox_ruleset_options::CreateInboxRulesetOptions;
 pub mod create_template_options;
@@ -94,6 +96,12 @@ pub mod html_validation_result;
 pub use self::html_validation_result::HtmlValidationResult;
 pub mod inbox;
 pub use self::inbox::Inbox;
+pub mod inbox_forwarder_dto;
+pub use self::inbox_forwarder_dto::InboxForwarderDto;
+pub mod inbox_forwarder_test_options;
+pub use self::inbox_forwarder_test_options::InboxForwarderTestOptions;
+pub mod inbox_forwarder_test_result;
+pub use self::inbox_forwarder_test_result::InboxForwarderTestResult;
 pub mod inbox_projection;
 pub use self::inbox_projection::InboxProjection;
 pub mod inbox_ruleset_dto;
@@ -130,6 +138,8 @@ pub mod page_expired_inbox_record_projection;
 pub use self::page_expired_inbox_record_projection::PageExpiredInboxRecordProjection;
 pub mod page_group_projection;
 pub use self::page_group_projection::PageGroupProjection;
+pub mod page_inbox_forwarder_dto;
+pub use self::page_inbox_forwarder_dto::PageInboxForwarderDto;
 pub mod page_inbox_projection;
 pub use self::page_inbox_projection::PageInboxProjection;
 pub mod page_inbox_ruleset_dto;
@@ -176,6 +186,8 @@ pub mod template_projection;
 pub use self::template_projection::TemplateProjection;
 pub mod template_variable;
 pub use self::template_variable::TemplateVariable;
+pub mod test_new_inbox_forwarder_options;
+pub use self::test_new_inbox_forwarder_options::TestNewInboxForwarderOptions;
 pub mod test_new_inbox_ruleset_options;
 pub use self::test_new_inbox_ruleset_options::TestNewInboxRulesetOptions;
 pub mod thread_projection;
